@@ -48,7 +48,7 @@
 
 #include "atl2.h"
 
-#define ATL2_DRV_VERSION "2.0.3"
+#define ATL2_DRV_VERSION "2.0.5"
 
 char atl2_driver_name[] = "atl2";
 static const char atl2_driver_string[] = "Atheros(R) L2 Ethernet Driver";
@@ -918,7 +918,8 @@ atl2_xmit_frame(struct sk_buff *skb, struct net_device *netdev)
 	txs_unused = TxsFreeUnit(adapter);
 	txbuf_unused = TxdFreeBytes(adapter);
 
-	if (txs_unused < 1 || skb->len > txbuf_unused) {
+	if (skb->len + sizeof(tx_pkt_header_t) + 4  > txbuf_unused ||
+		txs_unused < 1 ) {
 		// no enough resource
 		netif_stop_queue(netdev);
 		spin_unlock_irqrestore(&adapter->tx_lock, flags);
@@ -1448,7 +1449,6 @@ atl2_probe(struct pci_dev *pdev, const struct pci_device_id *ent)
 	if(!netdev)
 		goto err_alloc_etherdev;
 
-	SET_MODULE_OWNER(netdev);
 	SET_NETDEV_DEV(netdev, &pdev->dev);
 
 	pci_set_drvdata(pdev, netdev);
